@@ -12,7 +12,6 @@
 #include <QStringBuilder>
 
 #include "models/actionsmodel.h"
-#include "models/customemojimodel.h"
 #include "neochatconfig.h"
 #include "texthandler.h"
 
@@ -40,7 +39,8 @@ void ActionsHandler::setRoom(NeoChatRoom *room)
 
 void ActionsHandler::handleMessageEvent(ChatBarCache *chatBarCache)
 {
-    if (!chatBarCache) {
+    if (!m_room || !chatBarCache) {
+        qWarning() << "ActionsHandler::handleMessageEvent - called with m_room and/or chatBarCache set to nullptr.";
         return;
     }
 
@@ -61,10 +61,6 @@ void ActionsHandler::handleMessageEvent(ChatBarCache *chatBarCache)
 
 QString ActionsHandler::handleMentions(QString handledText, QList<Mention> *mentions)
 {
-    if (!m_room) {
-        return QString();
-    }
-
     std::sort(mentions->begin(), mentions->end(), [](const auto &a, const auto &b) -> bool {
         return a.cursor.anchor() > b.cursor.anchor();
     });
@@ -135,7 +131,6 @@ void ActionsHandler::handleMessage(const QString &text, QString handledText, Cha
         }
     }
 
-    handledText = CustomEmojiModel::instance().preprocessText(handledText);
     TextHandler textHandler;
     textHandler.setData(handledText);
     handledText = textHandler.handleSendText();
